==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/SourceRevisionFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class SourceRevisionFluentImpl<A extends io.fabric8.openshift.api.model.SourceRevisionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.SourceRevisionFluent<A>{
  public SourceRevisionFluentImpl() {
  }
  public SourceRevisionFluentImpl(io.fabric8.openshift.api.model.SourceRevision instance) {
    this.withGit(instance.getGit()); 
    this.withType(instance.getType()); 
  }
  private io.fabric8.openshift.api.model.GitSourceRevisionBuilder git;
  private java.lang.String type;
  
  /**
   * This method has been deprecated, please use method buildGit instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.GitSourceRevision getGit() {
    return this.git!=null?this.git.build():null;
  }
  public io.fabric8.openshift.api.model.GitSourceRevision buildGit() {
    return this.git!=null?this.git.build():null;
  }
  public A withGit(io.fabric8.openshift.api.model.GitSourceRevision git) {
    _visitables.get("git").remove(this.git);
    if (git!=null){ this.git= new io.fabric8.openshift.api.model.GitSourceRevisionBuilder(git); _visitables.get("git").add(this.git);} return (A) this;
  }
  public java.lang.Boolean hasGit() {
    return this.git != null;
  }
  public io.fabric8.openshift.api.model.SourceRevisionFluent.GitNested<A> withNewGit() {
    return new io.fabric8.openshift.api.model.SourceRevisionFluentImpl.GitNestedImpl();
  }
  public io.fabric8.openshift.api.model.SourceRevisionFluent.GitNested<A> withNewGitLike(io.fabric8.openshift.api.model.GitSourceRevision item) {
    return new io.fabric8.openshift.api.model.SourceRevisionFluentImpl.GitNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.SourceRevisionFluent.GitNested<A> editGit() {
    return withNewGitLike(getGit());
  }
  public io.fabric8.openshift.api.model.SourceRevisionFluent.GitNested<A> editOrNewGit() {
    return withNewGitLike(getGit() != null ? getGit(): new io.fabric8.openshift.api.model.GitSourceRevisionBuilder().build());
  }
  public io.fabric8.openshift.api.model.SourceRevisionFluent.GitNested<A> editOrNewGitLike(io.fabric8.openshift.api.model.GitSourceRevision item) {
    return withNewGitLike(getGit() != null ? getGit(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SourceRevisionFluentImpl that = (SourceRevisionFluentImpl) o;
    if (git != null ? !git.equals(that.git) :that.git != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(git,  type,  super.hashCode());
  }
  public class GitNestedImpl<N> extends io.fabric8.openshift.api.model.GitSourceRevisionFluentImpl<io.fabric8.openshift.api.model.SourceRevisionFluent.GitNested<N>> implements io.fabric8.openshift.api.model.SourceRevisionFluent.GitNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    GitNestedImpl(io.fabric8.openshift.api.model.GitSourceRevision item) {
      this.builder = new io.fabric8.openshift.api.model.GitSourceRevisionBuilder(this, item);
    }
    GitNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.GitSourceRevisionBuilder(this);
    }
    io.fabric8.openshift.api.model.GitSourceRevisionBuilder builder;
    public N and() {
      return (N) SourceRevisionFluentImpl.this.withGit(builder.build());
    }
    public N endGit() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/SourceRevisionFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class SourceRevisionFluentImpl<A extends io.fabric8.openshift.api.model.SourceRevisionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.SourceRevisionFluent<A>{
  public SourceRevisionFluentImpl() {
  }
  public SourceRevisionFluentImpl(io.fabric8.openshift.api.model.SourceRevision instance) {
    this.withGit(instance.getGit()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.GitSourceRevisionBuilder git;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildGit instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.GitSourceRevision getGit() {
    return this.git!=null?this.git.build():null;
  }
  public io.fabric8.openshift.api.model.GitSourceRevision buildGit() {
    return this.git!=null?this.git.build():null;
  }
  public A withGit(io.fabric8.openshift.api.model.GitSourceRevision git) {
    _visitables.get("git").remove(this.git);
    if (git!=null){ this.git= new io.fabric8.openshift.api.model.GitSourceRevisionBuilder(git); _visitables.get("git").add(this.git);} return (A) this;
  }
  public java.lang.Boolean hasGit() {
    return this.git != null;
  }
  public io.fabric8.openshift.api.model.SourceRevisionFluent.GitNested<A> withNewGit() {
    return new io.fabric8.openshift.api.model.SourceRevisionFluentImpl.GitNestedImpl();
  }
  public io.fabric8.openshift.api.model.SourceRevisionFluent.GitNested<A> withNewGitLike(io.fabric8.openshift.api.model.GitSourceRevision item) {
    return new io.fabric8.openshift.api.model.SourceRevisionFluentImpl.GitNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.SourceRevisionFluent.GitNested<A> editGit() {
    return withNewGitLike(getGit());
  }
  public io.fabric8.openshift.api.model.SourceRevisionFluent.GitNested<A> editOrNewGit() {
    return withNewGitLike(getGit() != null ? getGit(): new io.fabric8.openshift.api.model.GitSourceRevisionBuilder().build());
  }
  public io.fabric8.openshift.api.model.SourceRevisionFluent.GitNested<A> editOrNewGitLike(io.fabric8.openshift.api.model.GitSourceRevision item) {
    return withNewGitLike(getGit() != null ? getGit(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SourceRevisionFluentImpl that = (SourceRevisionFluentImpl) o;
    if (git != null ? !git.equals(that.git) :that.git != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(git,  type,  additionalProperties,  super.hashCode());
  }
  public class GitNestedImpl<N> extends io.fabric8.openshift.api.model.GitSourceRevisionFluentImpl<io.fabric8.openshift.api.model.SourceRevisionFluent.GitNested<N>> implements io.fabric8.openshift.api.model.SourceRevisionFluent.GitNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    GitNestedImpl(io.fabric8.openshift.api.model.GitSourceRevision item) {
      this.builder = new io.fabric8.openshift.api.model.GitSourceRevisionBuilder(this, item);
    }
    GitNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.GitSourceRevisionBuilder(this);
    }
    io.fabric8.openshift.api.model.GitSourceRevisionBuilder builder;
    public N and() {
      return (N) SourceRevisionFluentImpl.this.withGit(builder.build());
    }
    public N endGit() {
      return and();
    }
    
  }
  
}
